@@ -36,16 +36,16 @@
 #' 
 #' @examples
 #' 
-#' data(data)
+#' data(datafake)
 #' 
 #' # Example with a qualitative and a quantitative tables
 #' #The argument y.label is stored in the desc object and 
 #' # only used after by the regroup function
 #' 
-#'tab1=report.quanti(data=data,y="y_numeric",
+#'tab1=report.quanti(data=datafake,y="y_numeric",
 #'		x1="GROUP",subjid="SUBJID",y.label="Y numeric")
 #'
-#'tab2=report.quali(data=data,y="y_logistic",
+#'tab2=report.quali(data=datafake,y="y_logistic",
 #'		x1="GROUP",subjid="SUBJID",y.label="Y logistic")
 #'
 #'regroup(tab1,tab2,rbind.label="The label of your choice")
@@ -53,12 +53,12 @@
 #' 
 #' # Example with 2 quantitative tables
 #' 
-#'tab1=report.quanti(data=data,y="y_numeric",
+#'tab1=report.quanti(data=datafake,y="y_numeric",
 #'		x1="GROUP",subjid="SUBJID",y.label="Y numeric")
 #'
-#' data$y_numeric2=rnorm(length(data$y_numeric))
+#' datafake$y_numeric2=rnorm(length(datafake$y_numeric))
 #' 
-#'tab2=report.quanti(data=data,y="y_numeric2",
+#'tab2=report.quanti(data=datafake,y="y_numeric2",
 #'		x1="GROUP",subjid="SUBJID",y.label="Y Numeric 2")
 #'
 #'regroup(tab1,tab2,rbind.label="The label of your choice")
@@ -254,7 +254,10 @@ regroup.desc=function(x,y,rbind.label="Response",...)
 	}
 	
 	
-	
+	if(x$type.desc=="quali" & y$type.desc=="quali")
+	{
+		message("The regroup function doesn't work yet with two 'quali' objects")
+	}
 	
 	
 	
