@@ -8,11 +8,7 @@ knitr::opts_chunk$set(
 library(ClinReport)
 library(officer)
 library(flextable)
-library(dplyr)
-library(reshape2)
-library(nlme)
 library(emmeans)
-library(car)
 
 ## ---- include=TRUE-------------------------------------------------------
 # We will use fake data
@@ -43,13 +39,6 @@ func.stat.name="Effect size")
 report.doc(tab,title="Example of a specific statistic reporting",
 colspan.value="Treatment group")
 
-## ------------------------------------------------------------------------
-tab=report.quali(data=datafake,y="y_logistic",x1="GROUP",
-total=TRUE,subjid="SUBJID",percent.col=FALSE)
-
-report.doc(tab,title="Example of row percentage reporting",
-colspan.value="Treatment group")
-
 ## ------------------------------------------------------------------------
 # The default statistics are given here:
  
@@ -92,3 +81,46 @@ tab=report.quanti(data=datafake,y="y_numeric",x1="GROUP",
  colspan.value="Treatment Group")
 
 
+## ------------------------------------------------------------------------
+tab=report.quali(data=datafake,y="y_logistic",x1="GROUP",
+total=TRUE,subjid="SUBJID",percent.col=FALSE)
+
+report.doc(tab,title="Example of row percentage reporting",
+colspan.value="Treatment group")
+
+## ------------------------------------------------------------------------
+tab=report.quali(data=datafake,y="y_logistic",x1="GROUP",
+subjid="SUBJID",drop.x1=c("B","C"))
+
+report.doc(tab,title="Example of row percentage reporting",
+colspan.value="Treatment group")
+
+## ------------------------------------------------------------------------
+tab=report.quali(data=datafake,y="y_logistic",x1="GROUP",
+remove.missing=TRUE)
+
+report.doc(tab,title="Example of dropping missing values",
+colspan.value="Treatment group")
+
+## ------------------------------------------------------------------------
+
+tab=report.quali(data=datafake,
+y="y_logistic",x1="GROUP",
+subjid="SUBJID",remove.missing=T)
+
+# The default output
+report.doc(tab)
+
+# The transposed output
+report.doc(transpose(tab))
+
+
+## ------------------------------------------------------------------------
+mod=lm(y_numeric~GROUP,data=datafake)
+pairs=pairs(emmeans(mod,~GROUP))
+
+tab=report.lsmeans(pairs,transpose=TRUE)
+
+report.doc(tab,title="Example of transposing LS-Means in column",
+colspan.value="Treatment group")
+
