@@ -17,7 +17,7 @@ library(car)
 ## ---- include=TRUE-------------------------------------------------------
 # We will use fake data
 data(datafake)
-print(head(data))
+print(head(datafake))
 
 ## ---- include=TRUE-------------------------------------------------------
 tab1=report.quanti(data=datafake,y="y_numeric",
@@ -96,15 +96,48 @@ tab3=regroup(tab1,tab2,rbind.label="The label of your choice")
 report.doc(tab3,title="Mixed Qualitative and Quantitative outputs",
 colspan.value="Treatment group")
 
+## ------------------------------------------------------------------------
+# We use a fake standard adverse event data set
+# In this data sets there are several observations per subject
+# and the factor PTNAME is a sub classification of the factor SOCNAME
+
+data(adverse_event)
+
+# In the report.quali.hlev we specify which factor has the more levels in the var_upper
+# argument. The var_lower argument indicates the classification with less levels.
+# The x1 argument is used to split the results according to the levels of another factor.
+
+test=report.quali.hlev(data=adverse_event,subjid="SUBJID",var_upper="PTNAME",
+var_lower="SOCNAME",lower.levels="System Organ Class",upper.levels="Prefered Terms",x1="randtrt")
+
+# Frequencies and Percentages for each level are shown in the 
+# formatted table in HTML, using the usual report.doc function
+
+ft=report.doc(test,valign=TRUE)
+ft
+
 ## ------------------------------------------------------------------------
 # Removing baseline data for the model
+
 data.mod=droplevels(datafake[datafake$TIMEPOINT!="D0",])
 
 mod=lme(y_numeric~baseline+GROUP+TIMEPOINT+GROUP*TIMEPOINT,
 random=~1|SUBJID,data=data.mod,na.action=na.omit)
  
+report.modelinfo(mod)
+
+## ------------------------------------------------------------------------
+# Removing baseline data for the model
+
 anov3=Anova(mod,3)
 
+# Make pretty names for the table
+
+rownames(anov3)=make.label(rownames(anov3),
+list(c("GROUP","Treatment"),
+c("TIMEPOINT","Visit"),
+c("Treatment:Visit","Interaction Treatment-Visit")))
+
 report.doc(anov3,title="Mixed Qualitative and Quantitative output")
 
 ## ------------------------------------------------------------------------
@@ -141,3 +174,6 @@ tab.pairs
 report.doc(tab.pairs,title="Hazard ratios of a Cox model")
 
 
+## ------------------------------------------------------------------------
+report.sessionInfo()
+
